==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mount/translations/mount_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.ui" line="44"/>
        <source>Click to access this device from other applications.</source>
        <translation>点击以从其它应用程序访问此设备。</translation>
    </message>
    <message>
        <location filename="../menudiskitem.ui" line="57"/>
        <source>Click to eject this disc.</source>
        <translation>点击以弹出该存储卷。</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <location filename="../mountbutton.cpp" line="185"/>
        <source>Removable media/devices manager</source>
        <translation>可移动存储设备管理器</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="280"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>设备 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; 已连接。</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="299"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>设备 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; 已移除。</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="342"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is mounted to %2</source>
        <translation>设备 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; 被挂载到 %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="356"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is unmounted&lt;br&gt;
Now you can eject USB Flash or CD/DVD Disk.</source>
        <translation>设备 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; 已卸载&lt;br&gt;
现在你可以弹出该U盘或CD/DVD光盘了。</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="388"/>
        <source>Can&apos;t mount device: %1&lt;br&gt;
%2</source>
        <translation>无法挂载设备: %1&lt;br&gt;
%2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="394"/>
        <source>Device &apos;%1&apos; is mounted to %2</source>
        <translation>设备 &apos;%1&apos; 被挂载到 %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="424"/>
        <source>Can&apos;t unmount device: %1&lt;br&gt;
%2</source>
        <translation>无法卸载设备: %1&lt;br&gt;
%2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="428"/>
        <source>Device &apos;%1&apos; is unmounted</source>
        <translation>设备 &apos;%1&apos; 已卸载</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="444"/>
        <source>No devices Available.</source>
        <translation>没有可用设备。</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <location filename="../razormountconfiguration.ui" line="14"/>
        <source>Razor Removable media manager settings</source>
        <translation>Razor可移动媒体管理器设置</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>行为</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="26"/>
        <source>When a device is connected </source>
        <translation>当一个设备连接时</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="43"/>
        <source>Popup menu</source>
        <translation>弹出菜单</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="44"/>
        <source>Show info</source>
        <translation>显示信息</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="45"/>
        <source>Do nothing</source>
        <translation>什么都不做</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mount/translations/mount_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>点击以从其它应用程序访问此设备。</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>点击以弹出该存储卷。</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>可移动存储设备管理器</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>设备 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; 已连接。</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>设备 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; 已移除。</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <source>No devices are available</source>
        <translation>无可用的设备</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <source>Razor Removable media manager settings</source>
        <translation>Razor可移动媒体管理器设置</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>行为</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>当一个设备连接时</translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>弹出菜单</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>显示信息</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>什么都不做</translation>
    </message>
</context>
</TS>
